# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class ModelsStoreApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def models_store_delete_model(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1DeleteModelResponse':  # noqa: E501
        """DeleteModel is used to delete the model and all uploaded archives  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_delete_model(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1DeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_delete_model_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_delete_model_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
            return data

    def models_store_delete_model_with_http_info(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1DeleteModelResponse':  # noqa: E501
        """DeleteModel is used to delete the model and all uploaded archives  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_delete_model_with_http_info(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1DeleteModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_delete_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `models_store_delete_model`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `models_store_delete_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/models/{modelId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_delete_model_version(self, project_id: 'str', model_id: 'str', version: 'str', **kwargs) -> 'V1DeleteModelVersionResponse':  # noqa: E501
        """DeleteModelVersion is used to delete a specific model version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_delete_model_version(project_id, model_id, version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :param str version: (required)
        :return: V1DeleteModelVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_delete_model_version_with_http_info(project_id, model_id, version, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_delete_model_version_with_http_info(project_id, model_id, version, **kwargs)  # noqa: E501
            return data

    def models_store_delete_model_version_with_http_info(self, project_id: 'str', model_id: 'str', version: 'str', **kwargs) -> 'V1DeleteModelVersionResponse':  # noqa: E501
        """DeleteModelVersion is used to delete a specific model version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_delete_model_version_with_http_info(project_id, model_id, version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :param str version: (required)
        :return: V1DeleteModelVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'model_id', 'version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_delete_model_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `models_store_delete_model_version`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `models_store_delete_model_version`")  # noqa: E501
        # verify the required parameter 'version' is set
        if ('version' not in params or
                params['version'] is None):
            raise ValueError("Missing the required parameter `version` when calling `models_store_delete_model_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501
        if 'version' in params:
            path_params['version'] = params['version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/models/{modelId}/versions/{version}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteModelVersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_download_model(self, **kwargs) -> 'V1DownloadModelResponse':  # noqa: E501
        """DownloadModel is a public facing API used by the Python library to get a presigned URL to download the model. Name is a required query parameter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_download_model(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param str version:
        :return: V1DownloadModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_download_model_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.models_store_download_model_with_http_info(**kwargs)  # noqa: E501
            return data

    def models_store_download_model_with_http_info(self, **kwargs) -> 'V1DownloadModelResponse':  # noqa: E501
        """DownloadModel is a public facing API used by the Python library to get a presigned URL to download the model. Name is a required query parameter  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_download_model_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param str version:
        :return: V1DownloadModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_download_model" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'version' in params:
            query_params.append(('version', params['version']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DownloadModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_get_model(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1Model':  # noqa: E501
        """GetModel used to get specific model details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_get_model(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1Model
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_get_model_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_get_model_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
            return data

    def models_store_get_model_with_http_info(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1Model':  # noqa: E501
        """GetModel used to get specific model details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_get_model_with_http_info(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1Model
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_get_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `models_store_get_model`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `models_store_get_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/models/{modelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Model',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_list_model_versions(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1ListModelVersionsResponse':  # noqa: E501
        """models_store_list_model_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_list_model_versions(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1ListModelVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_list_model_versions_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_list_model_versions_with_http_info(project_id, model_id, **kwargs)  # noqa: E501
            return data

    def models_store_list_model_versions_with_http_info(self, project_id: 'str', model_id: 'str', **kwargs) -> 'V1ListModelVersionsResponse':  # noqa: E501
        """models_store_list_model_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_list_model_versions_with_http_info(project_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str model_id: (required)
        :return: V1ListModelVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_list_model_versions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `models_store_list_model_versions`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `models_store_list_model_versions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/models/{modelId}/versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListModelVersionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_list_models(self, project_id: 'str', **kwargs) -> 'V1ListModelsResponse':  # noqa: E501
        """ListModels used to list all models that belong to the project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_list_models(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_list_models_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_list_models_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def models_store_list_models_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListModelsResponse':  # noqa: E501
        """ListModels used to list all models that belong to the project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_list_models_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1ListModelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_list_models" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `models_store_list_models`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListModelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def models_store_upload_model(self, body: 'V1UploadModelRequest', **kwargs) -> 'V1UploadModelResponse':  # noqa: E501
        """UploadModel used to upload a new model version. It will either create a new top level model entry or reuse existing if an existing model is found. If version is not supplied, it will overwrite 'latest' version entry.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_upload_model(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UploadModelRequest body: (required)
        :return: V1UploadModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.models_store_upload_model_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.models_store_upload_model_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def models_store_upload_model_with_http_info(self, body: 'V1UploadModelRequest', **kwargs) -> 'V1UploadModelResponse':  # noqa: E501
        """UploadModel used to upload a new model version. It will either create a new top level model entry or reuse existing if an existing model is found. If version is not supplied, it will overwrite 'latest' version entry.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.models_store_upload_model_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UploadModelRequest body: (required)
        :return: V1UploadModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method models_store_upload_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `models_store_upload_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/models', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UploadModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GalleryApp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_entrypoint_file': 'str',
        'authors': 'list[str]',
        'auto_start': 'bool',
        'can_download_source_code': 'bool',
        'can_run': 'bool',
        'categories': 'list[str]',
        'components': 'list[str]',
        'description': 'str',
        'display_name': 'str',
        'example_code': 'str',
        'flow_servers': 'list[V1Flowserver]',
        'git_url': 'str',
        'id': 'str',
        'installation_code': 'str',
        'license': 'str',
        'name': 'str',
        'open_url': 'str',
        'org_logo': 'str',
        'organization': 'str',
        'requirements_path': 'str',
        'short_description': 'str',
        'source_url': 'str',
        'tags': 'list[str]',
        'target_admin_tab': 'str',
        'template_tags': 'list[str]',
        'thumbnail': 'str',
        'version': 'str',
        'video': 'str',
        'visibility': 'str',
        'works': 'list[V1Work]'
    }

    attribute_map = {
        'app_entrypoint_file': 'appEntrypointFile',
        'authors': 'authors',
        'auto_start': 'autoStart',
        'can_download_source_code': 'canDownloadSourceCode',
        'can_run': 'canRun',
        'categories': 'categories',
        'components': 'components',
        'description': 'description',
        'display_name': 'displayName',
        'example_code': 'exampleCode',
        'flow_servers': 'flowServers',
        'git_url': 'gitUrl',
        'id': 'id',
        'installation_code': 'installationCode',
        'license': 'license',
        'name': 'name',
        'open_url': 'openUrl',
        'org_logo': 'orgLogo',
        'organization': 'organization',
        'requirements_path': 'requirementsPath',
        'short_description': 'shortDescription',
        'source_url': 'sourceUrl',
        'tags': 'tags',
        'target_admin_tab': 'targetAdminTab',
        'template_tags': 'templateTags',
        'thumbnail': 'thumbnail',
        'version': 'version',
        'video': 'video',
        'visibility': 'visibility',
        'works': 'works'
    }

    def __init__(self, app_entrypoint_file: 'str' =None, authors: 'list[str]' =None, auto_start: 'bool' =None, can_download_source_code: 'bool' =None, can_run: 'bool' =None, categories: 'list[str]' =None, components: 'list[str]' =None, description: 'str' =None, display_name: 'str' =None, example_code: 'str' =None, flow_servers: 'list[V1Flowserver]' =None, git_url: 'str' =None, id: 'str' =None, installation_code: 'str' =None, license: 'str' =None, name: 'str' =None, open_url: 'str' =None, org_logo: 'str' =None, organization: 'str' =None, requirements_path: 'str' =None, short_description: 'str' =None, source_url: 'str' =None, tags: 'list[str]' =None, target_admin_tab: 'str' =None, template_tags: 'list[str]' =None, thumbnail: 'str' =None, version: 'str' =None, video: 'str' =None, visibility: 'str' =None, works: 'list[V1Work]' =None):  # noqa: E501
        """V1GalleryApp - a model defined in Swagger"""  # noqa: E501
        self._app_entrypoint_file = None
        self._authors = None
        self._auto_start = None
        self._can_download_source_code = None
        self._can_run = None
        self._categories = None
        self._components = None
        self._description = None
        self._display_name = None
        self._example_code = None
        self._flow_servers = None
        self._git_url = None
        self._id = None
        self._installation_code = None
        self._license = None
        self._name = None
        self._open_url = None
        self._org_logo = None
        self._organization = None
        self._requirements_path = None
        self._short_description = None
        self._source_url = None
        self._tags = None
        self._target_admin_tab = None
        self._template_tags = None
        self._thumbnail = None
        self._version = None
        self._video = None
        self._visibility = None
        self._works = None
        self.discriminator = None
        if app_entrypoint_file is not None:
            self.app_entrypoint_file = app_entrypoint_file
        if authors is not None:
            self.authors = authors
        if auto_start is not None:
            self.auto_start = auto_start
        if can_download_source_code is not None:
            self.can_download_source_code = can_download_source_code
        if can_run is not None:
            self.can_run = can_run
        if categories is not None:
            self.categories = categories
        if components is not None:
            self.components = components
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if example_code is not None:
            self.example_code = example_code
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if git_url is not None:
            self.git_url = git_url
        if id is not None:
            self.id = id
        if installation_code is not None:
            self.installation_code = installation_code
        if license is not None:
            self.license = license
        if name is not None:
            self.name = name
        if open_url is not None:
            self.open_url = open_url
        if org_logo is not None:
            self.org_logo = org_logo
        if organization is not None:
            self.organization = organization
        if requirements_path is not None:
            self.requirements_path = requirements_path
        if short_description is not None:
            self.short_description = short_description
        if source_url is not None:
            self.source_url = source_url
        if tags is not None:
            self.tags = tags
        if target_admin_tab is not None:
            self.target_admin_tab = target_admin_tab
        if template_tags is not None:
            self.template_tags = template_tags
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if version is not None:
            self.version = version
        if video is not None:
            self.video = video
        if visibility is not None:
            self.visibility = visibility
        if works is not None:
            self.works = works

    @property
    def app_entrypoint_file(self) -> 'str':
        """Gets the app_entrypoint_file of this V1GalleryApp.  # noqa: E501


        :return: The app_entrypoint_file of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._app_entrypoint_file

    @app_entrypoint_file.setter
    def app_entrypoint_file(self, app_entrypoint_file: 'str'):
        """Sets the app_entrypoint_file of this V1GalleryApp.


        :param app_entrypoint_file: The app_entrypoint_file of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._app_entrypoint_file = app_entrypoint_file

    @property
    def authors(self) -> 'list[str]':
        """Gets the authors of this V1GalleryApp.  # noqa: E501


        :return: The authors of this V1GalleryApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._authors

    @authors.setter
    def authors(self, authors: 'list[str]'):
        """Sets the authors of this V1GalleryApp.


        :param authors: The authors of this V1GalleryApp.  # noqa: E501
        :type: list[str]
        """

        self._authors = authors

    @property
    def auto_start(self) -> 'bool':
        """Gets the auto_start of this V1GalleryApp.  # noqa: E501


        :return: The auto_start of this V1GalleryApp.  # noqa: E501
        :rtype: bool
        """
        return self._auto_start

    @auto_start.setter
    def auto_start(self, auto_start: 'bool'):
        """Sets the auto_start of this V1GalleryApp.


        :param auto_start: The auto_start of this V1GalleryApp.  # noqa: E501
        :type: bool
        """

        self._auto_start = auto_start

    @property
    def can_download_source_code(self) -> 'bool':
        """Gets the can_download_source_code of this V1GalleryApp.  # noqa: E501


        :return: The can_download_source_code of this V1GalleryApp.  # noqa: E501
        :rtype: bool
        """
        return self._can_download_source_code

    @can_download_source_code.setter
    def can_download_source_code(self, can_download_source_code: 'bool'):
        """Sets the can_download_source_code of this V1GalleryApp.


        :param can_download_source_code: The can_download_source_code of this V1GalleryApp.  # noqa: E501
        :type: bool
        """

        self._can_download_source_code = can_download_source_code

    @property
    def can_run(self) -> 'bool':
        """Gets the can_run of this V1GalleryApp.  # noqa: E501


        :return: The can_run of this V1GalleryApp.  # noqa: E501
        :rtype: bool
        """
        return self._can_run

    @can_run.setter
    def can_run(self, can_run: 'bool'):
        """Sets the can_run of this V1GalleryApp.


        :param can_run: The can_run of this V1GalleryApp.  # noqa: E501
        :type: bool
        """

        self._can_run = can_run

    @property
    def categories(self) -> 'list[str]':
        """Gets the categories of this V1GalleryApp.  # noqa: E501


        :return: The categories of this V1GalleryApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories: 'list[str]'):
        """Sets the categories of this V1GalleryApp.


        :param categories: The categories of this V1GalleryApp.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def components(self) -> 'list[str]':
        """Gets the components of this V1GalleryApp.  # noqa: E501


        :return: The components of this V1GalleryApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._components

    @components.setter
    def components(self, components: 'list[str]'):
        """Sets the components of this V1GalleryApp.


        :param components: The components of this V1GalleryApp.  # noqa: E501
        :type: list[str]
        """

        self._components = components

    @property
    def description(self) -> 'str':
        """Gets the description of this V1GalleryApp.  # noqa: E501


        :return: The description of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1GalleryApp.


        :param description: The description of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1GalleryApp.  # noqa: E501


        :return: The display_name of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1GalleryApp.


        :param display_name: The display_name of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def example_code(self) -> 'str':
        """Gets the example_code of this V1GalleryApp.  # noqa: E501


        :return: The example_code of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._example_code

    @example_code.setter
    def example_code(self, example_code: 'str'):
        """Sets the example_code of this V1GalleryApp.


        :param example_code: The example_code of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._example_code = example_code

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this V1GalleryApp.  # noqa: E501


        :return: The flow_servers of this V1GalleryApp.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this V1GalleryApp.


        :param flow_servers: The flow_servers of this V1GalleryApp.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def git_url(self) -> 'str':
        """Gets the git_url of this V1GalleryApp.  # noqa: E501


        :return: The git_url of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._git_url

    @git_url.setter
    def git_url(self, git_url: 'str'):
        """Sets the git_url of this V1GalleryApp.


        :param git_url: The git_url of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._git_url = git_url

    @property
    def id(self) -> 'str':
        """Gets the id of this V1GalleryApp.  # noqa: E501


        :return: The id of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1GalleryApp.


        :param id: The id of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def installation_code(self) -> 'str':
        """Gets the installation_code of this V1GalleryApp.  # noqa: E501


        :return: The installation_code of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._installation_code

    @installation_code.setter
    def installation_code(self, installation_code: 'str'):
        """Sets the installation_code of this V1GalleryApp.


        :param installation_code: The installation_code of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._installation_code = installation_code

    @property
    def license(self) -> 'str':
        """Gets the license of this V1GalleryApp.  # noqa: E501


        :return: The license of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license: 'str'):
        """Sets the license of this V1GalleryApp.


        :param license: The license of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def name(self) -> 'str':
        """Gets the name of this V1GalleryApp.  # noqa: E501


        :return: The name of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1GalleryApp.


        :param name: The name of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def open_url(self) -> 'str':
        """Gets the open_url of this V1GalleryApp.  # noqa: E501


        :return: The open_url of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._open_url

    @open_url.setter
    def open_url(self, open_url: 'str'):
        """Sets the open_url of this V1GalleryApp.


        :param open_url: The open_url of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._open_url = open_url

    @property
    def org_logo(self) -> 'str':
        """Gets the org_logo of this V1GalleryApp.  # noqa: E501


        :return: The org_logo of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._org_logo

    @org_logo.setter
    def org_logo(self, org_logo: 'str'):
        """Sets the org_logo of this V1GalleryApp.


        :param org_logo: The org_logo of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._org_logo = org_logo

    @property
    def organization(self) -> 'str':
        """Gets the organization of this V1GalleryApp.  # noqa: E501


        :return: The organization of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization: 'str'):
        """Sets the organization of this V1GalleryApp.


        :param organization: The organization of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._organization = organization

    @property
    def requirements_path(self) -> 'str':
        """Gets the requirements_path of this V1GalleryApp.  # noqa: E501


        :return: The requirements_path of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._requirements_path

    @requirements_path.setter
    def requirements_path(self, requirements_path: 'str'):
        """Sets the requirements_path of this V1GalleryApp.


        :param requirements_path: The requirements_path of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._requirements_path = requirements_path

    @property
    def short_description(self) -> 'str':
        """Gets the short_description of this V1GalleryApp.  # noqa: E501


        :return: The short_description of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description: 'str'):
        """Sets the short_description of this V1GalleryApp.


        :param short_description: The short_description of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def source_url(self) -> 'str':
        """Gets the source_url of this V1GalleryApp.  # noqa: E501


        :return: The source_url of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._source_url

    @source_url.setter
    def source_url(self, source_url: 'str'):
        """Sets the source_url of this V1GalleryApp.


        :param source_url: The source_url of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._source_url = source_url

    @property
    def tags(self) -> 'list[str]':
        """Gets the tags of this V1GalleryApp.  # noqa: E501


        :return: The tags of this V1GalleryApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[str]'):
        """Sets the tags of this V1GalleryApp.


        :param tags: The tags of this V1GalleryApp.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_admin_tab(self) -> 'str':
        """Gets the target_admin_tab of this V1GalleryApp.  # noqa: E501


        :return: The target_admin_tab of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._target_admin_tab

    @target_admin_tab.setter
    def target_admin_tab(self, target_admin_tab: 'str'):
        """Sets the target_admin_tab of this V1GalleryApp.


        :param target_admin_tab: The target_admin_tab of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._target_admin_tab = target_admin_tab

    @property
    def template_tags(self) -> 'list[str]':
        """Gets the template_tags of this V1GalleryApp.  # noqa: E501


        :return: The template_tags of this V1GalleryApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._template_tags

    @template_tags.setter
    def template_tags(self, template_tags: 'list[str]'):
        """Sets the template_tags of this V1GalleryApp.


        :param template_tags: The template_tags of this V1GalleryApp.  # noqa: E501
        :type: list[str]
        """

        self._template_tags = template_tags

    @property
    def thumbnail(self) -> 'str':
        """Gets the thumbnail of this V1GalleryApp.  # noqa: E501


        :return: The thumbnail of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail: 'str'):
        """Sets the thumbnail of this V1GalleryApp.


        :param thumbnail: The thumbnail of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def version(self) -> 'str':
        """Gets the version of this V1GalleryApp.  # noqa: E501


        :return: The version of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this V1GalleryApp.


        :param version: The version of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def video(self) -> 'str':
        """Gets the video of this V1GalleryApp.  # noqa: E501


        :return: The video of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._video

    @video.setter
    def video(self, video: 'str'):
        """Sets the video of this V1GalleryApp.


        :param video: The video of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._video = video

    @property
    def visibility(self) -> 'str':
        """Gets the visibility of this V1GalleryApp.  # noqa: E501


        :return: The visibility of this V1GalleryApp.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility: 'str'):
        """Sets the visibility of this V1GalleryApp.


        :param visibility: The visibility of this V1GalleryApp.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def works(self) -> 'list[V1Work]':
        """Gets the works of this V1GalleryApp.  # noqa: E501


        :return: The works of this V1GalleryApp.  # noqa: E501
        :rtype: list[V1Work]
        """
        return self._works

    @works.setter
    def works(self, works: 'list[V1Work]'):
        """Sets the works of this V1GalleryApp.


        :param works: The works of this V1GalleryApp.  # noqa: E501
        :type: list[V1Work]
        """

        self._works = works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GalleryApp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GalleryApp') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GalleryApp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GalleryApp') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class ProjectIdCloudspacesBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_download_source_code': 'bool',
        'cloud_space_instance_cpu_image_override': 'str',
        'cloud_space_instance_gpu_image_override': 'str',
        'cluster_id': 'str',
        'compute_name': 'str',
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'disk_size': 'str',
        'display_name': 'str',
        'name': 'str',
        'preemptible': 'bool'
    }

    attribute_map = {
        'can_download_source_code': 'canDownloadSourceCode',
        'cloud_space_instance_cpu_image_override': 'cloudSpaceInstanceCpuImageOverride',
        'cloud_space_instance_gpu_image_override': 'cloudSpaceInstanceGpuImageOverride',
        'cluster_id': 'clusterId',
        'compute_name': 'computeName',
        'data_connection_mounts': 'dataConnectionMounts',
        'disk_size': 'diskSize',
        'display_name': 'displayName',
        'name': 'name',
        'preemptible': 'preemptible'
    }

    def __init__(self, can_download_source_code: 'bool' =None, cloud_space_instance_cpu_image_override: 'str' =None, cloud_space_instance_gpu_image_override: 'str' =None, cluster_id: 'str' =None, compute_name: 'str' =None, data_connection_mounts: 'list[V1DataConnectionMount]' =None, disk_size: 'str' =None, display_name: 'str' =None, name: 'str' =None, preemptible: 'bool' =None):  # noqa: E501
        """ProjectIdCloudspacesBody - a model defined in Swagger"""  # noqa: E501
        self._can_download_source_code = None
        self._cloud_space_instance_cpu_image_override = None
        self._cloud_space_instance_gpu_image_override = None
        self._cluster_id = None
        self._compute_name = None
        self._data_connection_mounts = None
        self._disk_size = None
        self._display_name = None
        self._name = None
        self._preemptible = None
        self.discriminator = None
        if can_download_source_code is not None:
            self.can_download_source_code = can_download_source_code
        if cloud_space_instance_cpu_image_override is not None:
            self.cloud_space_instance_cpu_image_override = cloud_space_instance_cpu_image_override
        if cloud_space_instance_gpu_image_override is not None:
            self.cloud_space_instance_gpu_image_override = cloud_space_instance_gpu_image_override
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if compute_name is not None:
            self.compute_name = compute_name
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if disk_size is not None:
            self.disk_size = disk_size
        if display_name is not None:
            self.display_name = display_name
        if name is not None:
            self.name = name
        if preemptible is not None:
            self.preemptible = preemptible

    @property
    def can_download_source_code(self) -> 'bool':
        """Gets the can_download_source_code of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The can_download_source_code of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: bool
        """
        return self._can_download_source_code

    @can_download_source_code.setter
    def can_download_source_code(self, can_download_source_code: 'bool'):
        """Sets the can_download_source_code of this ProjectIdCloudspacesBody.


        :param can_download_source_code: The can_download_source_code of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: bool
        """

        self._can_download_source_code = can_download_source_code

    @property
    def cloud_space_instance_cpu_image_override(self) -> 'str':
        """Gets the cloud_space_instance_cpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The cloud_space_instance_cpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_instance_cpu_image_override

    @cloud_space_instance_cpu_image_override.setter
    def cloud_space_instance_cpu_image_override(self, cloud_space_instance_cpu_image_override: 'str'):
        """Sets the cloud_space_instance_cpu_image_override of this ProjectIdCloudspacesBody.


        :param cloud_space_instance_cpu_image_override: The cloud_space_instance_cpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._cloud_space_instance_cpu_image_override = cloud_space_instance_cpu_image_override

    @property
    def cloud_space_instance_gpu_image_override(self) -> 'str':
        """Gets the cloud_space_instance_gpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The cloud_space_instance_gpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_instance_gpu_image_override

    @cloud_space_instance_gpu_image_override.setter
    def cloud_space_instance_gpu_image_override(self, cloud_space_instance_gpu_image_override: 'str'):
        """Sets the cloud_space_instance_gpu_image_override of this ProjectIdCloudspacesBody.


        :param cloud_space_instance_gpu_image_override: The cloud_space_instance_gpu_image_override of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._cloud_space_instance_gpu_image_override = cloud_space_instance_gpu_image_override

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The cluster_id of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this ProjectIdCloudspacesBody.


        :param cluster_id: The cluster_id of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def compute_name(self) -> 'str':
        """Gets the compute_name of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The compute_name of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._compute_name

    @compute_name.setter
    def compute_name(self, compute_name: 'str'):
        """Sets the compute_name of this ProjectIdCloudspacesBody.


        :param compute_name: The compute_name of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._compute_name = compute_name

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The data_connection_mounts of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this ProjectIdCloudspacesBody.


        :param data_connection_mounts: The data_connection_mounts of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def disk_size(self) -> 'str':
        """Gets the disk_size of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The disk_size of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._disk_size

    @disk_size.setter
    def disk_size(self, disk_size: 'str'):
        """Sets the disk_size of this ProjectIdCloudspacesBody.


        :param disk_size: The disk_size of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._disk_size = disk_size

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The display_name of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this ProjectIdCloudspacesBody.


        :param display_name: The display_name of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def name(self) -> 'str':
        """Gets the name of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The name of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this ProjectIdCloudspacesBody.


        :param name: The name of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def preemptible(self) -> 'bool':
        """Gets the preemptible of this ProjectIdCloudspacesBody.  # noqa: E501


        :return: The preemptible of this ProjectIdCloudspacesBody.  # noqa: E501
        :rtype: bool
        """
        return self._preemptible

    @preemptible.setter
    def preemptible(self, preemptible: 'bool'):
        """Sets the preemptible of this ProjectIdCloudspacesBody.


        :param preemptible: The preemptible of this ProjectIdCloudspacesBody.  # noqa: E501
        :type: bool
        """

        self._preemptible = preemptible

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectIdCloudspacesBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'ProjectIdCloudspacesBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectIdCloudspacesBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'ProjectIdCloudspacesBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ClusterStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aws_v1_region_status': 'list[V1AWSDirectV1Status]',
        'dependency_service_health': 'list[V1ServiceHealth]',
        'driver_status': 'V1ClusterDriverStatus',
        'gridlet_version': 'str',
        'last_healthcheck_timestamp': 'datetime',
        'phase': 'V1ClusterState',
        'prometheus_endpoint': 'str',
        'queue_endpoint': 'str',
        'reason': 'str',
        'slurm_v1_status': 'V1SlurmV1Status',
        'ssh_gateway_endpoint': 'str',
        'storage_endpoint': 'str'
    }

    attribute_map = {
        'aws_v1_region_status': 'awsV1RegionStatus',
        'dependency_service_health': 'dependencyServiceHealth',
        'driver_status': 'driverStatus',
        'gridlet_version': 'gridletVersion',
        'last_healthcheck_timestamp': 'lastHealthcheckTimestamp',
        'phase': 'phase',
        'prometheus_endpoint': 'prometheusEndpoint',
        'queue_endpoint': 'queueEndpoint',
        'reason': 'reason',
        'slurm_v1_status': 'slurmV1Status',
        'ssh_gateway_endpoint': 'sshGatewayEndpoint',
        'storage_endpoint': 'storageEndpoint'
    }

    def __init__(self, aws_v1_region_status: 'list[V1AWSDirectV1Status]' =None, dependency_service_health: 'list[V1ServiceHealth]' =None, driver_status: 'V1ClusterDriverStatus' =None, gridlet_version: 'str' =None, last_healthcheck_timestamp: 'datetime' =None, phase: 'V1ClusterState' =None, prometheus_endpoint: 'str' =None, queue_endpoint: 'str' =None, reason: 'str' =None, slurm_v1_status: 'V1SlurmV1Status' =None, ssh_gateway_endpoint: 'str' =None, storage_endpoint: 'str' =None):  # noqa: E501
        """V1ClusterStatus - a model defined in Swagger"""  # noqa: E501
        self._aws_v1_region_status = None
        self._dependency_service_health = None
        self._driver_status = None
        self._gridlet_version = None
        self._last_healthcheck_timestamp = None
        self._phase = None
        self._prometheus_endpoint = None
        self._queue_endpoint = None
        self._reason = None
        self._slurm_v1_status = None
        self._ssh_gateway_endpoint = None
        self._storage_endpoint = None
        self.discriminator = None
        if aws_v1_region_status is not None:
            self.aws_v1_region_status = aws_v1_region_status
        if dependency_service_health is not None:
            self.dependency_service_health = dependency_service_health
        if driver_status is not None:
            self.driver_status = driver_status
        if gridlet_version is not None:
            self.gridlet_version = gridlet_version
        if last_healthcheck_timestamp is not None:
            self.last_healthcheck_timestamp = last_healthcheck_timestamp
        if phase is not None:
            self.phase = phase
        if prometheus_endpoint is not None:
            self.prometheus_endpoint = prometheus_endpoint
        if queue_endpoint is not None:
            self.queue_endpoint = queue_endpoint
        if reason is not None:
            self.reason = reason
        if slurm_v1_status is not None:
            self.slurm_v1_status = slurm_v1_status
        if ssh_gateway_endpoint is not None:
            self.ssh_gateway_endpoint = ssh_gateway_endpoint
        if storage_endpoint is not None:
            self.storage_endpoint = storage_endpoint

    @property
    def aws_v1_region_status(self) -> 'list[V1AWSDirectV1Status]':
        """Gets the aws_v1_region_status of this V1ClusterStatus.  # noqa: E501


        :return: The aws_v1_region_status of this V1ClusterStatus.  # noqa: E501
        :rtype: list[V1AWSDirectV1Status]
        """
        return self._aws_v1_region_status

    @aws_v1_region_status.setter
    def aws_v1_region_status(self, aws_v1_region_status: 'list[V1AWSDirectV1Status]'):
        """Sets the aws_v1_region_status of this V1ClusterStatus.


        :param aws_v1_region_status: The aws_v1_region_status of this V1ClusterStatus.  # noqa: E501
        :type: list[V1AWSDirectV1Status]
        """

        self._aws_v1_region_status = aws_v1_region_status

    @property
    def dependency_service_health(self) -> 'list[V1ServiceHealth]':
        """Gets the dependency_service_health of this V1ClusterStatus.  # noqa: E501


        :return: The dependency_service_health of this V1ClusterStatus.  # noqa: E501
        :rtype: list[V1ServiceHealth]
        """
        return self._dependency_service_health

    @dependency_service_health.setter
    def dependency_service_health(self, dependency_service_health: 'list[V1ServiceHealth]'):
        """Sets the dependency_service_health of this V1ClusterStatus.


        :param dependency_service_health: The dependency_service_health of this V1ClusterStatus.  # noqa: E501
        :type: list[V1ServiceHealth]
        """

        self._dependency_service_health = dependency_service_health

    @property
    def driver_status(self) -> 'V1ClusterDriverStatus':
        """Gets the driver_status of this V1ClusterStatus.  # noqa: E501


        :return: The driver_status of this V1ClusterStatus.  # noqa: E501
        :rtype: V1ClusterDriverStatus
        """
        return self._driver_status

    @driver_status.setter
    def driver_status(self, driver_status: 'V1ClusterDriverStatus'):
        """Sets the driver_status of this V1ClusterStatus.


        :param driver_status: The driver_status of this V1ClusterStatus.  # noqa: E501
        :type: V1ClusterDriverStatus
        """

        self._driver_status = driver_status

    @property
    def gridlet_version(self) -> 'str':
        """Gets the gridlet_version of this V1ClusterStatus.  # noqa: E501


        :return: The gridlet_version of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._gridlet_version

    @gridlet_version.setter
    def gridlet_version(self, gridlet_version: 'str'):
        """Sets the gridlet_version of this V1ClusterStatus.


        :param gridlet_version: The gridlet_version of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._gridlet_version = gridlet_version

    @property
    def last_healthcheck_timestamp(self) -> 'datetime':
        """Gets the last_healthcheck_timestamp of this V1ClusterStatus.  # noqa: E501


        :return: The last_healthcheck_timestamp of this V1ClusterStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_healthcheck_timestamp

    @last_healthcheck_timestamp.setter
    def last_healthcheck_timestamp(self, last_healthcheck_timestamp: 'datetime'):
        """Sets the last_healthcheck_timestamp of this V1ClusterStatus.


        :param last_healthcheck_timestamp: The last_healthcheck_timestamp of this V1ClusterStatus.  # noqa: E501
        :type: datetime
        """

        self._last_healthcheck_timestamp = last_healthcheck_timestamp

    @property
    def phase(self) -> 'V1ClusterState':
        """Gets the phase of this V1ClusterStatus.  # noqa: E501


        :return: The phase of this V1ClusterStatus.  # noqa: E501
        :rtype: V1ClusterState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1ClusterState'):
        """Sets the phase of this V1ClusterStatus.


        :param phase: The phase of this V1ClusterStatus.  # noqa: E501
        :type: V1ClusterState
        """

        self._phase = phase

    @property
    def prometheus_endpoint(self) -> 'str':
        """Gets the prometheus_endpoint of this V1ClusterStatus.  # noqa: E501

        endpoint to get prometheus metrics from cluster workloads.  # noqa: E501

        :return: The prometheus_endpoint of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._prometheus_endpoint

    @prometheus_endpoint.setter
    def prometheus_endpoint(self, prometheus_endpoint: 'str'):
        """Sets the prometheus_endpoint of this V1ClusterStatus.

        endpoint to get prometheus metrics from cluster workloads.  # noqa: E501

        :param prometheus_endpoint: The prometheus_endpoint of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._prometheus_endpoint = prometheus_endpoint

    @property
    def queue_endpoint(self) -> 'str':
        """Gets the queue_endpoint of this V1ClusterStatus.  # noqa: E501


        :return: The queue_endpoint of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._queue_endpoint

    @queue_endpoint.setter
    def queue_endpoint(self, queue_endpoint: 'str'):
        """Sets the queue_endpoint of this V1ClusterStatus.


        :param queue_endpoint: The queue_endpoint of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._queue_endpoint = queue_endpoint

    @property
    def reason(self) -> 'str':
        """Gets the reason of this V1ClusterStatus.  # noqa: E501


        :return: The reason of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason: 'str'):
        """Sets the reason of this V1ClusterStatus.


        :param reason: The reason of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def slurm_v1_status(self) -> 'V1SlurmV1Status':
        """Gets the slurm_v1_status of this V1ClusterStatus.  # noqa: E501


        :return: The slurm_v1_status of this V1ClusterStatus.  # noqa: E501
        :rtype: V1SlurmV1Status
        """
        return self._slurm_v1_status

    @slurm_v1_status.setter
    def slurm_v1_status(self, slurm_v1_status: 'V1SlurmV1Status'):
        """Sets the slurm_v1_status of this V1ClusterStatus.


        :param slurm_v1_status: The slurm_v1_status of this V1ClusterStatus.  # noqa: E501
        :type: V1SlurmV1Status
        """

        self._slurm_v1_status = slurm_v1_status

    @property
    def ssh_gateway_endpoint(self) -> 'str':
        """Gets the ssh_gateway_endpoint of this V1ClusterStatus.  # noqa: E501

        ssh dns to be used to access lightning flow & work.  # noqa: E501

        :return: The ssh_gateway_endpoint of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_gateway_endpoint

    @ssh_gateway_endpoint.setter
    def ssh_gateway_endpoint(self, ssh_gateway_endpoint: 'str'):
        """Sets the ssh_gateway_endpoint of this V1ClusterStatus.

        ssh dns to be used to access lightning flow & work.  # noqa: E501

        :param ssh_gateway_endpoint: The ssh_gateway_endpoint of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._ssh_gateway_endpoint = ssh_gateway_endpoint

    @property
    def storage_endpoint(self) -> 'str':
        """Gets the storage_endpoint of this V1ClusterStatus.  # noqa: E501


        :return: The storage_endpoint of this V1ClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._storage_endpoint

    @storage_endpoint.setter
    def storage_endpoint(self, storage_endpoint: 'str'):
        """Sets the storage_endpoint of this V1ClusterStatus.


        :param storage_endpoint: The storage_endpoint of this V1ClusterStatus.  # noqa: E501
        :type: str
        """

        self._storage_endpoint = storage_endpoint

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ClusterStatus') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ClusterStatus') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class CloudspaceIdRunsBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_entrypoint_file': 'str',
        'cluster_id': 'str',
        'dependency_cache_key': 'str',
        'description': 'str',
        'enable_app_server': 'bool',
        'env': 'list[V1EnvVar]',
        'flow_servers': 'list[V1Flowserver]',
        'image_id': 'str',
        'image_spec': 'V1ImageSpec',
        'is_headless': 'bool',
        'is_published': 'bool',
        'local_source': 'bool',
        'network_config': 'list[V1NetworkConfig]',
        'parent_id': 'str',
        'should_mount_cloudspace_content': 'bool',
        'source_code_url': 'str',
        'user_id': 'str',
        'user_requested_flow_compute_config': 'V1UserRequestedFlowComputeConfig',
        'works': 'list[V1Work]'
    }

    attribute_map = {
        'app_entrypoint_file': 'appEntrypointFile',
        'cluster_id': 'clusterId',
        'dependency_cache_key': 'dependencyCacheKey',
        'description': 'description',
        'enable_app_server': 'enableAppServer',
        'env': 'env',
        'flow_servers': 'flowServers',
        'image_id': 'imageId',
        'image_spec': 'imageSpec',
        'is_headless': 'isHeadless',
        'is_published': 'isPublished',
        'local_source': 'localSource',
        'network_config': 'networkConfig',
        'parent_id': 'parentId',
        'should_mount_cloudspace_content': 'shouldMountCloudspaceContent',
        'source_code_url': 'sourceCodeUrl',
        'user_id': 'userId',
        'user_requested_flow_compute_config': 'userRequestedFlowComputeConfig',
        'works': 'works'
    }

    def __init__(self, app_entrypoint_file: 'str' =None, cluster_id: 'str' =None, dependency_cache_key: 'str' =None, description: 'str' =None, enable_app_server: 'bool' =None, env: 'list[V1EnvVar]' =None, flow_servers: 'list[V1Flowserver]' =None, image_id: 'str' =None, image_spec: 'V1ImageSpec' =None, is_headless: 'bool' =None, is_published: 'bool' =None, local_source: 'bool' =None, network_config: 'list[V1NetworkConfig]' =None, parent_id: 'str' =None, should_mount_cloudspace_content: 'bool' =None, source_code_url: 'str' =None, user_id: 'str' =None, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig' =None, works: 'list[V1Work]' =None):  # noqa: E501
        """CloudspaceIdRunsBody - a model defined in Swagger"""  # noqa: E501
        self._app_entrypoint_file = None
        self._cluster_id = None
        self._dependency_cache_key = None
        self._description = None
        self._enable_app_server = None
        self._env = None
        self._flow_servers = None
        self._image_id = None
        self._image_spec = None
        self._is_headless = None
        self._is_published = None
        self._local_source = None
        self._network_config = None
        self._parent_id = None
        self._should_mount_cloudspace_content = None
        self._source_code_url = None
        self._user_id = None
        self._user_requested_flow_compute_config = None
        self._works = None
        self.discriminator = None
        if app_entrypoint_file is not None:
            self.app_entrypoint_file = app_entrypoint_file
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if dependency_cache_key is not None:
            self.dependency_cache_key = dependency_cache_key
        if description is not None:
            self.description = description
        if enable_app_server is not None:
            self.enable_app_server = enable_app_server
        if env is not None:
            self.env = env
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if image_id is not None:
            self.image_id = image_id
        if image_spec is not None:
            self.image_spec = image_spec
        if is_headless is not None:
            self.is_headless = is_headless
        if is_published is not None:
            self.is_published = is_published
        if local_source is not None:
            self.local_source = local_source
        if network_config is not None:
            self.network_config = network_config
        if parent_id is not None:
            self.parent_id = parent_id
        if should_mount_cloudspace_content is not None:
            self.should_mount_cloudspace_content = should_mount_cloudspace_content
        if source_code_url is not None:
            self.source_code_url = source_code_url
        if user_id is not None:
            self.user_id = user_id
        if user_requested_flow_compute_config is not None:
            self.user_requested_flow_compute_config = user_requested_flow_compute_config
        if works is not None:
            self.works = works

    @property
    def app_entrypoint_file(self) -> 'str':
        """Gets the app_entrypoint_file of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The app_entrypoint_file of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._app_entrypoint_file

    @app_entrypoint_file.setter
    def app_entrypoint_file(self, app_entrypoint_file: 'str'):
        """Sets the app_entrypoint_file of this CloudspaceIdRunsBody.


        :param app_entrypoint_file: The app_entrypoint_file of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._app_entrypoint_file = app_entrypoint_file

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The cluster_id of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this CloudspaceIdRunsBody.


        :param cluster_id: The cluster_id of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def dependency_cache_key(self) -> 'str':
        """Gets the dependency_cache_key of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The dependency_cache_key of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._dependency_cache_key

    @dependency_cache_key.setter
    def dependency_cache_key(self, dependency_cache_key: 'str'):
        """Sets the dependency_cache_key of this CloudspaceIdRunsBody.


        :param dependency_cache_key: The dependency_cache_key of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._dependency_cache_key = dependency_cache_key

    @property
    def description(self) -> 'str':
        """Gets the description of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The description of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this CloudspaceIdRunsBody.


        :param description: The description of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enable_app_server(self) -> 'bool':
        """Gets the enable_app_server of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The enable_app_server of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: bool
        """
        return self._enable_app_server

    @enable_app_server.setter
    def enable_app_server(self, enable_app_server: 'bool'):
        """Sets the enable_app_server of this CloudspaceIdRunsBody.


        :param enable_app_server: The enable_app_server of this CloudspaceIdRunsBody.  # noqa: E501
        :type: bool
        """

        self._enable_app_server = enable_app_server

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The env of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this CloudspaceIdRunsBody.


        :param env: The env of this CloudspaceIdRunsBody.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The flow_servers of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this CloudspaceIdRunsBody.


        :param flow_servers: The flow_servers of this CloudspaceIdRunsBody.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def image_id(self) -> 'str':
        """Gets the image_id of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The image_id of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id: 'str'):
        """Sets the image_id of this CloudspaceIdRunsBody.


        :param image_id: The image_id of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def image_spec(self) -> 'V1ImageSpec':
        """Gets the image_spec of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The image_spec of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: V1ImageSpec
        """
        return self._image_spec

    @image_spec.setter
    def image_spec(self, image_spec: 'V1ImageSpec'):
        """Sets the image_spec of this CloudspaceIdRunsBody.


        :param image_spec: The image_spec of this CloudspaceIdRunsBody.  # noqa: E501
        :type: V1ImageSpec
        """

        self._image_spec = image_spec

    @property
    def is_headless(self) -> 'bool':
        """Gets the is_headless of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The is_headless of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_headless

    @is_headless.setter
    def is_headless(self, is_headless: 'bool'):
        """Sets the is_headless of this CloudspaceIdRunsBody.


        :param is_headless: The is_headless of this CloudspaceIdRunsBody.  # noqa: E501
        :type: bool
        """

        self._is_headless = is_headless

    @property
    def is_published(self) -> 'bool':
        """Gets the is_published of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The is_published of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published: 'bool'):
        """Sets the is_published of this CloudspaceIdRunsBody.


        :param is_published: The is_published of this CloudspaceIdRunsBody.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def local_source(self) -> 'bool':
        """Gets the local_source of this CloudspaceIdRunsBody.  # noqa: E501

        Indicates that the client wishes to upload the directory that has the source code. In this case, app's status is populated with the presigned URL and the app's spec is set by the server to the S3 tarball that holds the sourcecode.  # noqa: E501

        :return: The local_source of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: bool
        """
        return self._local_source

    @local_source.setter
    def local_source(self, local_source: 'bool'):
        """Sets the local_source of this CloudspaceIdRunsBody.

        Indicates that the client wishes to upload the directory that has the source code. In this case, app's status is populated with the presigned URL and the app's spec is set by the server to the S3 tarball that holds the sourcecode.  # noqa: E501

        :param local_source: The local_source of this CloudspaceIdRunsBody.  # noqa: E501
        :type: bool
        """

        self._local_source = local_source

    @property
    def network_config(self) -> 'list[V1NetworkConfig]':
        """Gets the network_config of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The network_config of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: list[V1NetworkConfig]
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config: 'list[V1NetworkConfig]'):
        """Sets the network_config of this CloudspaceIdRunsBody.


        :param network_config: The network_config of this CloudspaceIdRunsBody.  # noqa: E501
        :type: list[V1NetworkConfig]
        """

        self._network_config = network_config

    @property
    def parent_id(self) -> 'str':
        """Gets the parent_id of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The parent_id of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id: 'str'):
        """Sets the parent_id of this CloudspaceIdRunsBody.


        :param parent_id: The parent_id of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def should_mount_cloudspace_content(self) -> 'bool':
        """Gets the should_mount_cloudspace_content of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The should_mount_cloudspace_content of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: bool
        """
        return self._should_mount_cloudspace_content

    @should_mount_cloudspace_content.setter
    def should_mount_cloudspace_content(self, should_mount_cloudspace_content: 'bool'):
        """Sets the should_mount_cloudspace_content of this CloudspaceIdRunsBody.


        :param should_mount_cloudspace_content: The should_mount_cloudspace_content of this CloudspaceIdRunsBody.  # noqa: E501
        :type: bool
        """

        self._should_mount_cloudspace_content = should_mount_cloudspace_content

    @property
    def source_code_url(self) -> 'str':
        """Gets the source_code_url of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The source_code_url of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._source_code_url

    @source_code_url.setter
    def source_code_url(self, source_code_url: 'str'):
        """Sets the source_code_url of this CloudspaceIdRunsBody.


        :param source_code_url: The source_code_url of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._source_code_url = source_code_url

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The user_id of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this CloudspaceIdRunsBody.


        :param user_id: The user_id of this CloudspaceIdRunsBody.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_requested_flow_compute_config(self) -> 'V1UserRequestedFlowComputeConfig':
        """Gets the user_requested_flow_compute_config of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The user_requested_flow_compute_config of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: V1UserRequestedFlowComputeConfig
        """
        return self._user_requested_flow_compute_config

    @user_requested_flow_compute_config.setter
    def user_requested_flow_compute_config(self, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig'):
        """Sets the user_requested_flow_compute_config of this CloudspaceIdRunsBody.


        :param user_requested_flow_compute_config: The user_requested_flow_compute_config of this CloudspaceIdRunsBody.  # noqa: E501
        :type: V1UserRequestedFlowComputeConfig
        """

        self._user_requested_flow_compute_config = user_requested_flow_compute_config

    @property
    def works(self) -> 'list[V1Work]':
        """Gets the works of this CloudspaceIdRunsBody.  # noqa: E501


        :return: The works of this CloudspaceIdRunsBody.  # noqa: E501
        :rtype: list[V1Work]
        """
        return self._works

    @works.setter
    def works(self, works: 'list[V1Work]'):
        """Sets the works of this CloudspaceIdRunsBody.


        :param works: The works of this CloudspaceIdRunsBody.  # noqa: E501
        :type: list[V1Work]
        """

        self._works = works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudspaceIdRunsBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'CloudspaceIdRunsBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudspaceIdRunsBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'CloudspaceIdRunsBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GetFolderIndexResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'child_folder_names': 'list[str]',
        'last_modified_at': 'datetime',
        'nested_file_count': 'str',
        'page_size': 'int',
        'path': 'str',
        'size_bytes': 'str',
        'status': 'V1FolderIndexStatus'
    }

    attribute_map = {
        'child_folder_names': 'childFolderNames',
        'last_modified_at': 'lastModifiedAt',
        'nested_file_count': 'nestedFileCount',
        'page_size': 'pageSize',
        'path': 'path',
        'size_bytes': 'sizeBytes',
        'status': 'status'
    }

    def __init__(self, child_folder_names: 'list[str]' =None, last_modified_at: 'datetime' =None, nested_file_count: 'str' =None, page_size: 'int' =None, path: 'str' =None, size_bytes: 'str' =None, status: 'V1FolderIndexStatus' =None):  # noqa: E501
        """V1GetFolderIndexResponse - a model defined in Swagger"""  # noqa: E501
        self._child_folder_names = None
        self._last_modified_at = None
        self._nested_file_count = None
        self._page_size = None
        self._path = None
        self._size_bytes = None
        self._status = None
        self.discriminator = None
        if child_folder_names is not None:
            self.child_folder_names = child_folder_names
        if last_modified_at is not None:
            self.last_modified_at = last_modified_at
        if nested_file_count is not None:
            self.nested_file_count = nested_file_count
        if page_size is not None:
            self.page_size = page_size
        if path is not None:
            self.path = path
        if size_bytes is not None:
            self.size_bytes = size_bytes
        if status is not None:
            self.status = status

    @property
    def child_folder_names(self) -> 'list[str]':
        """Gets the child_folder_names of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The child_folder_names of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._child_folder_names

    @child_folder_names.setter
    def child_folder_names(self, child_folder_names: 'list[str]'):
        """Sets the child_folder_names of this V1GetFolderIndexResponse.


        :param child_folder_names: The child_folder_names of this V1GetFolderIndexResponse.  # noqa: E501
        :type: list[str]
        """

        self._child_folder_names = child_folder_names

    @property
    def last_modified_at(self) -> 'datetime':
        """Gets the last_modified_at of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The last_modified_at of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_at

    @last_modified_at.setter
    def last_modified_at(self, last_modified_at: 'datetime'):
        """Sets the last_modified_at of this V1GetFolderIndexResponse.


        :param last_modified_at: The last_modified_at of this V1GetFolderIndexResponse.  # noqa: E501
        :type: datetime
        """

        self._last_modified_at = last_modified_at

    @property
    def nested_file_count(self) -> 'str':
        """Gets the nested_file_count of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The nested_file_count of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: str
        """
        return self._nested_file_count

    @nested_file_count.setter
    def nested_file_count(self, nested_file_count: 'str'):
        """Sets the nested_file_count of this V1GetFolderIndexResponse.


        :param nested_file_count: The nested_file_count of this V1GetFolderIndexResponse.  # noqa: E501
        :type: str
        """

        self._nested_file_count = nested_file_count

    @property
    def page_size(self) -> 'int':
        """Gets the page_size of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The page_size of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size: 'int'):
        """Sets the page_size of this V1GetFolderIndexResponse.


        :param page_size: The page_size of this V1GetFolderIndexResponse.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def path(self) -> 'str':
        """Gets the path of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The path of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path: 'str'):
        """Sets the path of this V1GetFolderIndexResponse.


        :param path: The path of this V1GetFolderIndexResponse.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def size_bytes(self) -> 'str':
        """Gets the size_bytes of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The size_bytes of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: str
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes: 'str'):
        """Sets the size_bytes of this V1GetFolderIndexResponse.


        :param size_bytes: The size_bytes of this V1GetFolderIndexResponse.  # noqa: E501
        :type: str
        """

        self._size_bytes = size_bytes

    @property
    def status(self) -> 'V1FolderIndexStatus':
        """Gets the status of this V1GetFolderIndexResponse.  # noqa: E501


        :return: The status of this V1GetFolderIndexResponse.  # noqa: E501
        :rtype: V1FolderIndexStatus
        """
        return self._status

    @status.setter
    def status(self, status: 'V1FolderIndexStatus'):
        """Sets the status of this V1GetFolderIndexResponse.


        :param status: The status of this V1GetFolderIndexResponse.  # noqa: E501
        :type: V1FolderIndexStatus
        """

        self._status = status

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GetFolderIndexResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GetFolderIndexResponse') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GetFolderIndexResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GetFolderIndexResponse') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1CloudSpace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_download_source_code': 'bool',
        'cluster_id': 'str',
        'code_config': 'V1CloudSpaceInstanceConfig',
        'code_status': 'V1GetCloudSpaceInstanceStatusResponse',
        'created_at': 'datetime',
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'description': 'str',
        'display_name': 'str',
        'engagement_counts': 'dict(str, str)',
        'env': 'list[V1EnvVar]',
        'id': 'str',
        'image_status': 'V1ImageState',
        'is_cloudspace_private': 'bool',
        'is_code_private': 'bool',
        'is_published': 'bool',
        'message': 'str',
        'name': 'str',
        'number_of_files': 'str',
        'project_id': 'str',
        'published_at': 'datetime',
        'state': 'V1CloudSpaceState',
        'tags': 'list[V1CloudSpaceTag]',
        'thumbnail_file_type': 'str',
        'thumbnail_url': 'str',
        'total_size_bytes': 'str',
        'updated_at': 'datetime',
        'user_id': 'str',
        'user_metadata': 'str',
        'web_path': 'str'
    }

    attribute_map = {
        'can_download_source_code': 'canDownloadSourceCode',
        'cluster_id': 'clusterId',
        'code_config': 'codeConfig',
        'code_status': 'codeStatus',
        'created_at': 'createdAt',
        'data_connection_mounts': 'dataConnectionMounts',
        'description': 'description',
        'display_name': 'displayName',
        'engagement_counts': 'engagementCounts',
        'env': 'env',
        'id': 'id',
        'image_status': 'imageStatus',
        'is_cloudspace_private': 'isCloudspacePrivate',
        'is_code_private': 'isCodePrivate',
        'is_published': 'isPublished',
        'message': 'message',
        'name': 'name',
        'number_of_files': 'numberOfFiles',
        'project_id': 'projectId',
        'published_at': 'publishedAt',
        'state': 'state',
        'tags': 'tags',
        'thumbnail_file_type': 'thumbnailFileType',
        'thumbnail_url': 'thumbnailUrl',
        'total_size_bytes': 'totalSizeBytes',
        'updated_at': 'updatedAt',
        'user_id': 'userId',
        'user_metadata': 'userMetadata',
        'web_path': 'webPath'
    }

    def __init__(self, can_download_source_code: 'bool' =None, cluster_id: 'str' =None, code_config: 'V1CloudSpaceInstanceConfig' =None, code_status: 'V1GetCloudSpaceInstanceStatusResponse' =None, created_at: 'datetime' =None, data_connection_mounts: 'list[V1DataConnectionMount]' =None, description: 'str' =None, display_name: 'str' =None, engagement_counts: 'dict(str, str)' =None, env: 'list[V1EnvVar]' =None, id: 'str' =None, image_status: 'V1ImageState' =None, is_cloudspace_private: 'bool' =None, is_code_private: 'bool' =None, is_published: 'bool' =None, message: 'str' =None, name: 'str' =None, number_of_files: 'str' =None, project_id: 'str' =None, published_at: 'datetime' =None, state: 'V1CloudSpaceState' =None, tags: 'list[V1CloudSpaceTag]' =None, thumbnail_file_type: 'str' =None, thumbnail_url: 'str' =None, total_size_bytes: 'str' =None, updated_at: 'datetime' =None, user_id: 'str' =None, user_metadata: 'str' =None, web_path: 'str' =None):  # noqa: E501
        """V1CloudSpace - a model defined in Swagger"""  # noqa: E501
        self._can_download_source_code = None
        self._cluster_id = None
        self._code_config = None
        self._code_status = None
        self._created_at = None
        self._data_connection_mounts = None
        self._description = None
        self._display_name = None
        self._engagement_counts = None
        self._env = None
        self._id = None
        self._image_status = None
        self._is_cloudspace_private = None
        self._is_code_private = None
        self._is_published = None
        self._message = None
        self._name = None
        self._number_of_files = None
        self._project_id = None
        self._published_at = None
        self._state = None
        self._tags = None
        self._thumbnail_file_type = None
        self._thumbnail_url = None
        self._total_size_bytes = None
        self._updated_at = None
        self._user_id = None
        self._user_metadata = None
        self._web_path = None
        self.discriminator = None
        if can_download_source_code is not None:
            self.can_download_source_code = can_download_source_code
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if code_config is not None:
            self.code_config = code_config
        if code_status is not None:
            self.code_status = code_status
        if created_at is not None:
            self.created_at = created_at
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if engagement_counts is not None:
            self.engagement_counts = engagement_counts
        if env is not None:
            self.env = env
        if id is not None:
            self.id = id
        if image_status is not None:
            self.image_status = image_status
        if is_cloudspace_private is not None:
            self.is_cloudspace_private = is_cloudspace_private
        if is_code_private is not None:
            self.is_code_private = is_code_private
        if is_published is not None:
            self.is_published = is_published
        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if number_of_files is not None:
            self.number_of_files = number_of_files
        if project_id is not None:
            self.project_id = project_id
        if published_at is not None:
            self.published_at = published_at
        if state is not None:
            self.state = state
        if tags is not None:
            self.tags = tags
        if thumbnail_file_type is not None:
            self.thumbnail_file_type = thumbnail_file_type
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url
        if total_size_bytes is not None:
            self.total_size_bytes = total_size_bytes
        if updated_at is not None:
            self.updated_at = updated_at
        if user_id is not None:
            self.user_id = user_id
        if user_metadata is not None:
            self.user_metadata = user_metadata
        if web_path is not None:
            self.web_path = web_path

    @property
    def can_download_source_code(self) -> 'bool':
        """Gets the can_download_source_code of this V1CloudSpace.  # noqa: E501


        :return: The can_download_source_code of this V1CloudSpace.  # noqa: E501
        :rtype: bool
        """
        return self._can_download_source_code

    @can_download_source_code.setter
    def can_download_source_code(self, can_download_source_code: 'bool'):
        """Sets the can_download_source_code of this V1CloudSpace.


        :param can_download_source_code: The can_download_source_code of this V1CloudSpace.  # noqa: E501
        :type: bool
        """

        self._can_download_source_code = can_download_source_code

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1CloudSpace.  # noqa: E501


        :return: The cluster_id of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1CloudSpace.


        :param cluster_id: The cluster_id of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def code_config(self) -> 'V1CloudSpaceInstanceConfig':
        """Gets the code_config of this V1CloudSpace.  # noqa: E501


        :return: The code_config of this V1CloudSpace.  # noqa: E501
        :rtype: V1CloudSpaceInstanceConfig
        """
        return self._code_config

    @code_config.setter
    def code_config(self, code_config: 'V1CloudSpaceInstanceConfig'):
        """Sets the code_config of this V1CloudSpace.


        :param code_config: The code_config of this V1CloudSpace.  # noqa: E501
        :type: V1CloudSpaceInstanceConfig
        """

        self._code_config = code_config

    @property
    def code_status(self) -> 'V1GetCloudSpaceInstanceStatusResponse':
        """Gets the code_status of this V1CloudSpace.  # noqa: E501


        :return: The code_status of this V1CloudSpace.  # noqa: E501
        :rtype: V1GetCloudSpaceInstanceStatusResponse
        """
        return self._code_status

    @code_status.setter
    def code_status(self, code_status: 'V1GetCloudSpaceInstanceStatusResponse'):
        """Sets the code_status of this V1CloudSpace.


        :param code_status: The code_status of this V1CloudSpace.  # noqa: E501
        :type: V1GetCloudSpaceInstanceStatusResponse
        """

        self._code_status = code_status

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1CloudSpace.  # noqa: E501


        :return: The created_at of this V1CloudSpace.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1CloudSpace.


        :param created_at: The created_at of this V1CloudSpace.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this V1CloudSpace.  # noqa: E501


        :return: The data_connection_mounts of this V1CloudSpace.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this V1CloudSpace.


        :param data_connection_mounts: The data_connection_mounts of this V1CloudSpace.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def description(self) -> 'str':
        """Gets the description of this V1CloudSpace.  # noqa: E501


        :return: The description of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1CloudSpace.


        :param description: The description of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1CloudSpace.  # noqa: E501


        :return: The display_name of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1CloudSpace.


        :param display_name: The display_name of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def engagement_counts(self) -> 'dict(str, str)':
        """Gets the engagement_counts of this V1CloudSpace.  # noqa: E501


        :return: The engagement_counts of this V1CloudSpace.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._engagement_counts

    @engagement_counts.setter
    def engagement_counts(self, engagement_counts: 'dict(str, str)'):
        """Sets the engagement_counts of this V1CloudSpace.


        :param engagement_counts: The engagement_counts of this V1CloudSpace.  # noqa: E501
        :type: dict(str, str)
        """

        self._engagement_counts = engagement_counts

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this V1CloudSpace.  # noqa: E501


        :return: The env of this V1CloudSpace.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this V1CloudSpace.


        :param env: The env of this V1CloudSpace.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def id(self) -> 'str':
        """Gets the id of this V1CloudSpace.  # noqa: E501


        :return: The id of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1CloudSpace.


        :param id: The id of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image_status(self) -> 'V1ImageState':
        """Gets the image_status of this V1CloudSpace.  # noqa: E501


        :return: The image_status of this V1CloudSpace.  # noqa: E501
        :rtype: V1ImageState
        """
        return self._image_status

    @image_status.setter
    def image_status(self, image_status: 'V1ImageState'):
        """Sets the image_status of this V1CloudSpace.


        :param image_status: The image_status of this V1CloudSpace.  # noqa: E501
        :type: V1ImageState
        """

        self._image_status = image_status

    @property
    def is_cloudspace_private(self) -> 'bool':
        """Gets the is_cloudspace_private of this V1CloudSpace.  # noqa: E501


        :return: The is_cloudspace_private of this V1CloudSpace.  # noqa: E501
        :rtype: bool
        """
        return self._is_cloudspace_private

    @is_cloudspace_private.setter
    def is_cloudspace_private(self, is_cloudspace_private: 'bool'):
        """Sets the is_cloudspace_private of this V1CloudSpace.


        :param is_cloudspace_private: The is_cloudspace_private of this V1CloudSpace.  # noqa: E501
        :type: bool
        """

        self._is_cloudspace_private = is_cloudspace_private

    @property
    def is_code_private(self) -> 'bool':
        """Gets the is_code_private of this V1CloudSpace.  # noqa: E501


        :return: The is_code_private of this V1CloudSpace.  # noqa: E501
        :rtype: bool
        """
        return self._is_code_private

    @is_code_private.setter
    def is_code_private(self, is_code_private: 'bool'):
        """Sets the is_code_private of this V1CloudSpace.


        :param is_code_private: The is_code_private of this V1CloudSpace.  # noqa: E501
        :type: bool
        """

        self._is_code_private = is_code_private

    @property
    def is_published(self) -> 'bool':
        """Gets the is_published of this V1CloudSpace.  # noqa: E501


        :return: The is_published of this V1CloudSpace.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published: 'bool'):
        """Sets the is_published of this V1CloudSpace.


        :param is_published: The is_published of this V1CloudSpace.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def message(self) -> 'str':
        """Gets the message of this V1CloudSpace.  # noqa: E501


        :return: The message of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1CloudSpace.


        :param message: The message of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def name(self) -> 'str':
        """Gets the name of this V1CloudSpace.  # noqa: E501


        :return: The name of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1CloudSpace.


        :param name: The name of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def number_of_files(self) -> 'str':
        """Gets the number_of_files of this V1CloudSpace.  # noqa: E501


        :return: The number_of_files of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._number_of_files

    @number_of_files.setter
    def number_of_files(self, number_of_files: 'str'):
        """Sets the number_of_files of this V1CloudSpace.


        :param number_of_files: The number_of_files of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._number_of_files = number_of_files

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1CloudSpace.  # noqa: E501


        :return: The project_id of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1CloudSpace.


        :param project_id: The project_id of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def published_at(self) -> 'datetime':
        """Gets the published_at of this V1CloudSpace.  # noqa: E501


        :return: The published_at of this V1CloudSpace.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at: 'datetime'):
        """Sets the published_at of this V1CloudSpace.


        :param published_at: The published_at of this V1CloudSpace.  # noqa: E501
        :type: datetime
        """

        self._published_at = published_at

    @property
    def state(self) -> 'V1CloudSpaceState':
        """Gets the state of this V1CloudSpace.  # noqa: E501


        :return: The state of this V1CloudSpace.  # noqa: E501
        :rtype: V1CloudSpaceState
        """
        return self._state

    @state.setter
    def state(self, state: 'V1CloudSpaceState'):
        """Sets the state of this V1CloudSpace.


        :param state: The state of this V1CloudSpace.  # noqa: E501
        :type: V1CloudSpaceState
        """

        self._state = state

    @property
    def tags(self) -> 'list[V1CloudSpaceTag]':
        """Gets the tags of this V1CloudSpace.  # noqa: E501


        :return: The tags of this V1CloudSpace.  # noqa: E501
        :rtype: list[V1CloudSpaceTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[V1CloudSpaceTag]'):
        """Sets the tags of this V1CloudSpace.


        :param tags: The tags of this V1CloudSpace.  # noqa: E501
        :type: list[V1CloudSpaceTag]
        """

        self._tags = tags

    @property
    def thumbnail_file_type(self) -> 'str':
        """Gets the thumbnail_file_type of this V1CloudSpace.  # noqa: E501


        :return: The thumbnail_file_type of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_type

    @thumbnail_file_type.setter
    def thumbnail_file_type(self, thumbnail_file_type: 'str'):
        """Sets the thumbnail_file_type of this V1CloudSpace.


        :param thumbnail_file_type: The thumbnail_file_type of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_type = thumbnail_file_type

    @property
    def thumbnail_url(self) -> 'str':
        """Gets the thumbnail_url of this V1CloudSpace.  # noqa: E501


        :return: The thumbnail_url of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url: 'str'):
        """Sets the thumbnail_url of this V1CloudSpace.


        :param thumbnail_url: The thumbnail_url of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._thumbnail_url = thumbnail_url

    @property
    def total_size_bytes(self) -> 'str':
        """Gets the total_size_bytes of this V1CloudSpace.  # noqa: E501


        :return: The total_size_bytes of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._total_size_bytes

    @total_size_bytes.setter
    def total_size_bytes(self, total_size_bytes: 'str'):
        """Sets the total_size_bytes of this V1CloudSpace.


        :param total_size_bytes: The total_size_bytes of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._total_size_bytes = total_size_bytes

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1CloudSpace.  # noqa: E501


        :return: The updated_at of this V1CloudSpace.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1CloudSpace.


        :param updated_at: The updated_at of this V1CloudSpace.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1CloudSpace.  # noqa: E501


        :return: The user_id of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1CloudSpace.


        :param user_id: The user_id of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_metadata(self) -> 'str':
        """Gets the user_metadata of this V1CloudSpace.  # noqa: E501


        :return: The user_metadata of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata: 'str'):
        """Sets the user_metadata of this V1CloudSpace.


        :param user_metadata: The user_metadata of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._user_metadata = user_metadata

    @property
    def web_path(self) -> 'str':
        """Gets the web_path of this V1CloudSpace.  # noqa: E501


        :return: The web_path of this V1CloudSpace.  # noqa: E501
        :rtype: str
        """
        return self._web_path

    @web_path.setter
    def web_path(self, web_path: 'str'):
        """Sets the web_path of this V1CloudSpace.


        :param web_path: The web_path of this V1CloudSpace.  # noqa: E501
        :type: str
        """

        self._web_path = web_path

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1CloudSpace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1CloudSpace') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CloudSpace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1CloudSpace') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1Model(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'categories': 'list[str]',
        'created_at': 'datetime',
        'description': 'str',
        'downloads': 'str',
        'id': 'str',
        'license': 'str',
        'metadata': 'dict(str, str)',
        'name': 'str',
        'private': 'bool',
        'project_id': 'str',
        'tags': 'list[str]',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'categories': 'categories',
        'created_at': 'createdAt',
        'description': 'description',
        'downloads': 'downloads',
        'id': 'id',
        'license': 'license',
        'metadata': 'metadata',
        'name': 'name',
        'private': 'private',
        'project_id': 'projectId',
        'tags': 'tags',
        'updated_at': 'updatedAt'
    }

    def __init__(self, categories: 'list[str]' =None, created_at: 'datetime' =None, description: 'str' =None, downloads: 'str' =None, id: 'str' =None, license: 'str' =None, metadata: 'dict(str, str)' =None, name: 'str' =None, private: 'bool' =None, project_id: 'str' =None, tags: 'list[str]' =None, updated_at: 'datetime' =None):  # noqa: E501
        """V1Model - a model defined in Swagger"""  # noqa: E501
        self._categories = None
        self._created_at = None
        self._description = None
        self._downloads = None
        self._id = None
        self._license = None
        self._metadata = None
        self._name = None
        self._private = None
        self._project_id = None
        self._tags = None
        self._updated_at = None
        self.discriminator = None
        if categories is not None:
            self.categories = categories
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if downloads is not None:
            self.downloads = downloads
        if id is not None:
            self.id = id
        if license is not None:
            self.license = license
        if metadata is not None:
            self.metadata = metadata
        if name is not None:
            self.name = name
        if private is not None:
            self.private = private
        if project_id is not None:
            self.project_id = project_id
        if tags is not None:
            self.tags = tags
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def categories(self) -> 'list[str]':
        """Gets the categories of this V1Model.  # noqa: E501


        :return: The categories of this V1Model.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories: 'list[str]'):
        """Sets the categories of this V1Model.


        :param categories: The categories of this V1Model.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1Model.  # noqa: E501


        :return: The created_at of this V1Model.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1Model.


        :param created_at: The created_at of this V1Model.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self) -> 'str':
        """Gets the description of this V1Model.  # noqa: E501


        :return: The description of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1Model.


        :param description: The description of this V1Model.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def downloads(self) -> 'str':
        """Gets the downloads of this V1Model.  # noqa: E501


        :return: The downloads of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._downloads

    @downloads.setter
    def downloads(self, downloads: 'str'):
        """Sets the downloads of this V1Model.


        :param downloads: The downloads of this V1Model.  # noqa: E501
        :type: str
        """

        self._downloads = downloads

    @property
    def id(self) -> 'str':
        """Gets the id of this V1Model.  # noqa: E501


        :return: The id of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1Model.


        :param id: The id of this V1Model.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def license(self) -> 'str':
        """Gets the license of this V1Model.  # noqa: E501


        :return: The license of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license: 'str'):
        """Sets the license of this V1Model.


        :param license: The license of this V1Model.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def metadata(self) -> 'dict(str, str)':
        """Gets the metadata of this V1Model.  # noqa: E501


        :return: The metadata of this V1Model.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: 'dict(str, str)'):
        """Sets the metadata of this V1Model.


        :param metadata: The metadata of this V1Model.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def name(self) -> 'str':
        """Gets the name of this V1Model.  # noqa: E501


        :return: The name of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1Model.


        :param name: The name of this V1Model.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def private(self) -> 'bool':
        """Gets the private of this V1Model.  # noqa: E501


        :return: The private of this V1Model.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private: 'bool'):
        """Sets the private of this V1Model.


        :param private: The private of this V1Model.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1Model.  # noqa: E501


        :return: The project_id of this V1Model.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1Model.


        :param project_id: The project_id of this V1Model.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def tags(self) -> 'list[str]':
        """Gets the tags of this V1Model.  # noqa: E501


        :return: The tags of this V1Model.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[str]'):
        """Sets the tags of this V1Model.


        :param tags: The tags of this V1Model.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1Model.  # noqa: E501


        :return: The updated_at of this V1Model.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1Model.


        :param updated_at: The updated_at of this V1Model.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Model, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Model') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Model):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1Model') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
